@@ -1,19 +1,5 @@
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+// SPDX-License-Identifier: GPL-2.0+
 /* NetworkManager Connection editor -- Connection editor for NetworkManager
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  * Copyright 2008 - 2014 Red Hat, Inc.
  */
@@ -617,7 +603,7 @@ ui_to_setting (CEPageVlan *self)
 	VlanParent *parent = NULL;
 	int active_id, parent_id, vid;
 	const char *parent_iface = NULL, *parent_uuid = NULL;
-	const char *slave_type;
+	const char *port_type;
 	const char *iface;
 	char *tmp_parent_iface = NULL;
 	GType hwtype;
@@ -641,17 +627,17 @@ ui_to_setting (CEPageVlan *self)
 
 	g_assert (parent_uuid != NULL || parent_iface != NULL);
 
-	slave_type = nm_setting_connection_get_slave_type (s_con);
+	port_type = nm_setting_connection_get_slave_type (s_con);
 	if (parent_uuid) {
 		/* Update NMSettingConnection:master if it's set, but don't
 		 * set it if it's not.
 		 */
-		if (!g_strcmp0 (slave_type, NM_SETTING_VLAN_SETTING_NAME)) {
+		if (!g_strcmp0 (port_type, NM_SETTING_VLAN_SETTING_NAME)) {
 			g_object_set (s_con,
 			              NM_SETTING_CONNECTION_MASTER, parent_uuid,
 			              NULL);
 		}
-	} else if (!g_strcmp0 (slave_type, NM_SETTING_VLAN_SETTING_NAME)) {
+	} else if (!g_strcmp0 (port_type, NM_SETTING_VLAN_SETTING_NAME)) {
 		g_object_set (s_con,
 		              NM_SETTING_CONNECTION_MASTER, NULL,
 		              NM_SETTING_CONNECTION_SLAVE_TYPE, NULL,
